<?php

	/**
	 * Turkish language file for phpPgAdmin.  Use this as a basis
	 * for new translations.
	 *
	 * $Id: turkish.php,v 1.15 2007/04/24 11:42:07 soranzo Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Trke';
	$lang['appcharset'] = 'ISO-8859-9';
	$lang['applocale'] = 'tr_TR';
  	$lang['appdbencoding'] = 'LATIN5';
	$lang['applangdir'] = 'ltr';

	// Basic strings
	$lang['strintro'] = 'phpPgAdmin\'e hogeldiniz.';
	$lang['strppahome'] = 'phpPgAdmin Ana Sayfas';
	$lang['strpgsqlhome']  =  'PostgreSQL Ana Sayfas';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL Belgeleri (yerel)';
	$lang['strreportbug'] = 'Hata Bildirin';
	$lang['strviewfaq'] = 'Ska Sorulan Sorular';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin']  =  'Giri';
	$lang['strloginfailed'] = 'Giri Baarsz';
	$lang['strlogindisallowed']  =  'Gvenlik nedeniyle girie izin verilmedi.';
	$lang['strserver'] = 'Sunucu';
	$lang['strservers']  =  'Sunucular';
	$lang['strintroduction']  =  'Giri';
	$lang['strhost']  =  'Sunucu';
	$lang['strport']  =  'Port';
	$lang['strlogout'] = 'k';
	$lang['strowner'] = 'Sahibi';
	$lang['straction'] = 'Eylem';
	$lang['stractions'] = 'Eylemler';
	$lang['strname'] = 'Ad';
	$lang['strdefinition'] = 'Tanm';
	$lang['strproperties'] = 'zellikler';
	$lang['strbrowse'] = 'Gzat';
	$lang['strdrop'] = 'Sil';
	$lang['strdropped'] = 'Silindi';
	$lang['strnull'] = 'Null';
	$lang['strnotnull'] = 'Null/Null deil';
	$lang['strprev'] = 'nceki';
	$lang['strnext'] = 'Sonraki';
	$lang['strfirst'] = '<< lk';
	$lang['strlast'] = 'Son >>';
	$lang['strfailed']  =  'Baarsz oldu.';
	$lang['strcreate']  =  'Yarat';
	$lang['strcreated'] = 'Yaratld';
	$lang['strcomment'] = 'Yorum';
	$lang['strlength'] = 'Uzunluk';
	$lang['strdefault'] = 'n tanml deer';
	$lang['stralter'] = 'Deitir';
	$lang['strok'] = 'Tamam';
	$lang['strcancel'] = 'ptal Et';
	$lang['strsave'] = 'Kaydet';
	$lang['strreset'] = 'Temizle';
	$lang['strinsert'] = 'Ekle';
	$lang['strselect'] = 'Se';
	$lang['strdelete'] = 'Sil';
	$lang['strupdate'] = 'Gncelle';
	$lang['strreferences'] = 'References';
	$lang['stryes'] = 'Evet';
	$lang['strno'] = 'Hayr';
	$lang['strtrue']  =  'TRUE';
	$lang['strfalse']  =  'FALSE';
	$lang['stredit'] = 'Dzenle';
	$lang['strcolumn']  =  'KolonF';
	$lang['strcolumns'] = 'Kolonlar';
	$lang['strrows'] = 'satr';
	$lang['strrowsaff']  =  'satr ilendi.';
	$lang['strobjects']  =  'nesne(ler)';
	$lang['strback'] = 'Geri';
	$lang['strqueryresults'] = 'Sorgu sonular';
	$lang['strshow'] = 'Gster';
	$lang['strempty'] = 'Boalt';
	$lang['strlanguage'] = 'Dil';
	$lang['strencoding'] = 'Karakter kodlamas';
	$lang['strvalue'] = 'Deer';
	$lang['strunique'] = 'Tekil';
	$lang['strprimary'] = 'Birincil';
	$lang['strexport'] = 'Export';
	$lang['strimport']  =  'Import';
	$lang['strallowednulls']  =  'zin verilen NULL karakterler';
	$lang['strbackslashn']  =  '\N';
	$lang['strnull']  =  'Null';
	$lang['strnull']  =  'NULL (szck)';
	$lang['stremptystring']  =  'Bo metin/alan';
	$lang['strsql'] = 'SQL';
	$lang['stradmin'] = 'Ynetici';
	$lang['strvacuum'] = 'Vacuum';
	$lang['stranalyze'] = 'Analyze';
	$lang['strclusterindex'] = 'Cluster';
	$lang['strclustered']  =  'Cluster edildi mi?';
	$lang['strreindex'] = 'Reindex';
	$lang['strrun'] = 'altr';
	$lang['stradd'] = 'Ekle';
	$lang['strremove']  =  'Kaldr';
	$lang['strevent'] = 'Event';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = 'Do Instead';
	$lang['strwhen'] = 'When';
	$lang['strformat'] = 'Format';
	$lang['strdata'] = 'Veri';
	$lang['strconfirm'] = 'Onayla';
	$lang['strexpression'] = 'fade';
	$lang['strellipsis'] = '...';
	$lang['strseparator']  =  ': ';
	$lang['strexpand'] = 'Genilet';
	$lang['strcollapse']  =  'Dar grnm';
	$lang['strexplain'] = 'Explain';
	$lang['strexplainanalyze']  =  'Explain Analyze';
	$lang['strfind'] = 'Bul';
	$lang['stroptions'] = 'Seenekler';
	$lang['strrefresh'] = 'Yenile';
	$lang['strdownload'] = 'ndir';
	$lang['strdownloadgzipped']  =  'gzip ile sktrlm halde indir';
	$lang['strinfo']  =  'Bilgi';
	$lang['stroids']  =  'OIDler';
	$lang['stradvanced']  =  'Gelimi';
	$lang['strvariables']  =  'Deikenler';
	$lang['strprocess']  =  'Sre';
	$lang['strprocesses']  =  'Sreler';
	$lang['strsetting']  =  'Ayar';
	$lang['streditsql']  =  'SQL Dzenle';
	$lang['strruntime']  =  'Toplam alma sresi: %s ms';
	$lang['strpaginate']  =  'Sonular sayfalandr.';
	$lang['struploadscript']  =  'ya da bir SQL betii ykleyin:';
	$lang['strstarttime']  =  'Balang zaman';
	$lang['strfile']  =  'Dosya';
	$lang['strfileimported']  =  'Dosya import edildi.';
	$lang['strtrycred']  =  'Giri bilgilerini tm sunucular iin kullan';

	// Error handling
	$lang['strnoframes']  =  'Bu uygulama en iyi olarak frame destekli bir tarayc ile kullanlabilir; ancak frameler ile kullanmak istemiyorsanz aadaki linke tklayabilirsiniz.';
	$lang['strnoframeslink']  =  'Frame olmadan kullan';
	$lang['strbadconfig'] = 'config.inc.php dosyaniz gncel deil. Bu dosyay yeni config.inc.php-dist dosyasndan yaratmanz gerekmektedir.';
	$lang['strnotloaded'] = 'PHP kurulumunuzda PostgreSQL destei bulunamamtr.';
        $lang['strpostgresqlversionnotsupported'] = 'Bu PostgreSQL srm desteklenmemektedir. Ltfen %s ya da st bir srme gncelleyiniz.';
	$lang['strbadschema'] = 'Geersiz ema.';
	$lang['strbadencoding'] = 'stemci dil kodlamasn ayarlamaya alrken bir hata olutu.';
	$lang['strsqlerror'] = 'SQL hatas:';
	$lang['strinstatement'] = 'stteki hata, aadaki ifade iinde olutu:';
	$lang['strinvalidparam'] = 'Geersiz betik parametreleri.';
	$lang['strnodata'] = 'Satr bulunamad.';
	$lang['strnoobjects']  =  'Hibir nesne bulunamad..';
	$lang['strrownotunique']  =  'Bu satr iin hibir tekil belirtici bulunamad.';
	$lang['strnoreportsdb']  =  'reports veritaban yaratmam. Ynergeler iin ltfen INSTALL dosyasn okuyunuz.';
	$lang['strnouploads']  =  'Dosya ykleme zellii etkin deil.';
	$lang['strimporterror']  =  'Import hatas.';
	$lang['strimporterror-fileformat']  =  'Import hatas: Dosya tipi otomatik olarak belirlenemedi.';
	$lang['strimporterrorline']  =  '%s numaral satrda import hatas.';
$lang['strimporterrorline-badcolumnnum']  =  'Import error on line %s:  Line does not possess the correct number of columns.';
$lang['strimporterror-uploadedfile']  =  'Import error: File could not be uploaded to the server';
$lang['strcannotdumponwindows']  =  'Dumping of complex table and schema names on Windows is not supported.';

	// Tables
	$lang['strtable'] = 'Tablo';
	$lang['strtables'] = 'Tablolar';
	$lang['strshowalltables'] = 'Tm tablolar gster';
	$lang['strnotables'] = 'Veritabannda tablo bulunamad.';
	$lang['strnotable'] = 'Veritabannda tablo bulunamad.';
	$lang['strcreatetable'] = 'Yeni tablo yarat';
	$lang['strtablename'] = 'Tablo ad';
	$lang['strtableneedsname'] = 'Tablonuza bir ad vermeniz gerekmektedir.';
	$lang['strtableneedsfield'] = 'En az bir alan belirtmeniz gerekmektedir.';
	$lang['strtableneedscols'] = 'Geerli miktarda kolon says belirtmeniz gerekmektedir.';
	$lang['strtablecreated'] = 'Tablo yaratld.';
	$lang['strtablecreatedbad'] = 'Tablo yaratlamad.';
	$lang['strconfdroptable'] = '"%s" tablosunu kaldrmak istediinizden emin misiniz?';
	$lang['strtabledropped'] = 'Tablo kaldrld.';
	$lang['strtabledroppedbad'] = 'Tablo kaldrlamad.';
	$lang['strconfemptytable'] = '"%s" tablosunu boaltmak istediinizden emin misiniz?';
	$lang['strtableemptied'] = 'Tablo boaltld.';
	$lang['strtableemptiedbad'] = 'Tablo boaltlamad.';
	$lang['strinsertrow'] = 'Yeni kayt gir';
	$lang['strrowinserted'] = 'Yeni kayt girildi.';
	$lang['strrowinsertedbad'] = 'Yeni kayt girme ilemi baarsz oldu.';
	$lang['strrowduplicate']  =  'Satr ekleme baarsz oldu, birbirinin ayn iki kayt girilmek istendi.';
	$lang['streditrow'] = 'Kaydn ieriini deitir.';
	$lang['strrowupdated'] = 'Kayt gncellendi.';
	$lang['strrowupdatedbad'] = 'Kayt gncelleme ileme baarsz oldu.';
	$lang['strdeleterow'] = 'Kayd sil';
	$lang['strconfdeleterow'] = 'Bu kayd silmek istediinize emin misiniz?';
	$lang['strrowdeleted'] = 'Kayt silindi.';
	$lang['strrowdeletedbad'] = 'Kayt silinme ilemi baarsz oldu.';
        $lang['strinsertandrepeat'] = 'Ekle ve Tekrarla';
        $lang['strnumcols'] = 'Kolon says';
        $lang['strcolneedsname'] = 'Kolon iin bir ad vermelisiniz.';
	$lang['strselectallfields']  =  'Tm alanlar se';
	$lang['strselectneedscol'] = 'En az bir kolon iaretlemelisiniz';
	$lang['strselectunary']  =  'Unary operatrlerin deeri olamaz.';
	$lang['straltercolumn'] = 'Kolonu deitir (alter)';
	$lang['strcolumnaltered'] = 'Kolon deitirildi (alter)';
	$lang['strcolumnalteredbad'] = 'Kolon deitirilme ilemi baarsz oldu.';
	$lang['strconfdropcolumn']  =  '"%s" kolonunu "%s" tablosundan silmek istediinize emin misiniz?';
	$lang['strcolumndropped'] = 'Kolon silindi.';
	$lang['strcolumndroppedbad'] = 'Kolon silme ilemi baarsz oldu.';
	$lang['straddcolumn'] = 'Yeni kolon ekle';
	$lang['strcolumnadded'] = 'Kolon eklendi.';
	$lang['strcolumnaddedbad'] = 'Kolon eklenemedi.';
	$lang['strcascade']  =  'CASCADE';
	$lang['strtablealtered'] = 'Tablo alter edildi..';
	$lang['strtablealteredbad'] = 'Tablo alteration ilemi baarsz oldu.';
	$lang['strdataonly']  =  'Sadece veri';
	$lang['strstructureonly']  =  'Sadece yap';
	$lang['strstructureanddata']  =  'Yap ve veri';
	$lang['strtabbed']  =  'Tabbed';
	$lang['strauto']  =  'Otomatik';
	$lang['strconfvacuumtable'] = '"%s" tablosunu vakumlamak istediiniz emin misiniz?';
        $lang['strestimatedrowcount'] = 'Yaklak satr says';

	// Users
	$lang['struser'] = 'Kullanc';
	$lang['strusers'] = 'Kullanclar';
	$lang['strusername'] = 'Kullanc Ad';
	$lang['strpassword'] = 'ifresi';
	$lang['strsuper'] = 'Superuser m?';
	$lang['strcreatedb'] = 'Veritaban yaratabilsin mi?';
	$lang['strexpires'] = 'Expires';
	$lang['strsessiondefaults']  =  'Oturum varsaylanlar';
	$lang['strnousers']  =  'Hibir kullanc bulunamad.';
        $lang['struserupdated'] = 'Kullanc gncellendi.';
	$lang['struserupdatedbad'] = 'Kullanc gncelleme ilemi baarsz oldu.';
	$lang['strshowallusers'] = 'Tm kullanclar gster.';
	$lang['strcreateuser'] = 'Yeni kullanc yarat';
	$lang['struserneedsname']  =  'Kullancnz iin bir ad vermelisiniz.';
	$lang['strusercreated'] = 'Kullanc yaratld.';
	$lang['strusercreatedbad'] = 'Kullanc yaratlma ilemi baarsz oldu.';
	$lang['strconfdropuser'] = '"%s" kullancsn silmek istediinize emin misiniz?';
	$lang['struserdropped'] = 'Kullanc silindi.';
	$lang['struserdroppedbad'] = 'Kullanc silme ilemi baarsz oldu.';
	$lang['straccount'] = 'Hesap';
	$lang['strchangepassword'] = 'ifre Deitir';
	$lang['strpasswordchanged'] = 'ifre deitirildi.';
	$lang['strpasswordchangedbad'] = 'ifre deitirme baarsz oldu.';
	$lang['strpasswordshort']  =  'ifre ok ksa.';
	$lang['strpasswordconfirm'] = 'ifreler uyumad.';
	
	// Groups
	$lang['strgroup'] = 'Grup';
	$lang['strgroups'] = 'Gruplar';
	$lang['strnogroup'] = 'Grup bulunamad.';
	$lang['strnogroups'] = 'Grup bulunamad.';
	$lang['strcreategroup'] = 'Yeni grup yarat';
	$lang['strshowallgroups'] = 'Tm gruplar gster';
	$lang['strgroupneedsname'] = 'Grup yaratabilmek iin bir ad vermelisiniz.';
	$lang['strgroupcreated'] = 'Grup yaratld.';
	$lang['strgroupcreatedbad'] = 'Grup yaratma ilemi baarsz oldu.';	
	$lang['strconfdropgroup'] = '"%s" grubunu silmek istediinize emin misiniz?';
	$lang['strgroupdropped'] = 'Grup silindi.';
	$lang['strgroupdroppedbad'] = 'Grup silme ilemi baarsz oldu.';
	$lang['strmembers'] = 'yeler';
	$lang['straddmember'] = 'ye ekle';
	$lang['strmemberadded'] = 'ye eklendi.';
	$lang['strmemberaddedbad'] = 'ye ekleme baarsz oldu.';
	$lang['strdropmember'] = 'yeyi kaldr';
	$lang['strconfdropmember'] = '"%s" yesini "%s" grubundan silmek istediinize emin misiniz?';
	$lang['strmemberdropped'] = 'ye silindi.';
	$lang['strmemberdroppedbad'] = 'ye silme baarsz oldu.';

	// Privilges
	$lang['strprivilege'] = 'zni';
	$lang['strprivileges'] = 'zinler';
	$lang['strnoprivileges'] = 'Bu nesnenin bir izni yoktur.';
	$lang['strgrant'] = 'zni ver';
	$lang['strrevoke'] = 'zni kaldr';
	$lang['strgranted'] = 'zimler verildi.';
	$lang['strgrantfailed'] = 'zinlerin grant ilemi baarsz oldu.';

	$lang['strgrantbad'] = 'En az bir kullanc ya da grup ve en az bir izin belirtmelisiniz.';
	$lang['strgrantor'] = 'Grantor';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Veritaban';
	$lang['strdatabases'] = 'Veritabanlar';
	$lang['strshowalldatabases'] = 'Tm veritabanlarn gster';
	$lang['strnodatabase'] = 'Veritaban bulunamad.';
	$lang['strnodatabases'] = 'Veritaban bulunamad.';
	$lang['strcreatedatabase'] = 'Veritaban yarat';
	$lang['strdatabasename'] = 'Veritaban ad';
	$lang['strdatabaseneedsname'] = 'Veritabannza bir ad vermelisiniz.';
	$lang['strdatabasecreated'] = 'Veritaban yaratld.';
	$lang['strdatabasecreatedbad'] = 'Veritaban yaratlamad.';	
	$lang['strconfdropdatabase'] = '"%s" veritabann kaldrmak istediinize emin misiniz?';
	$lang['strdatabasedropped'] = 'Veritaban kaldrld.';
	$lang['strdatabasedroppedbad'] = 'Veritaban kaldrma baarsz oldu.';
	$lang['strentersql'] = 'Veritaban zerinde altrlacak sorgu/sorgular aaya yaznz:';
	$lang['strsqlexecuted'] = 'SQL altrld.';
	$lang['strvacuumgood']  =  'Vacuum tamamland.';
	$lang['strvacuumbad'] = 'Vacuum ilemi baarsz oldu.';
	$lang['stranalyzegood'] = 'Analyze ilemi tamamland.';
	$lang['stranalyzebad'] = 'Analyze ilemi baarsz oldu.';
	$lang['strreindexgood']  =  'Reindex tamamland.';
	$lang['strreindexbad']  =  'Reindex baarsz oldu.';
	$lang['strfull']  =  'Full';
	$lang['strfreeze']  =  'Freeze';
	$lang['strforce']  =  'Force';
	$lang['strsignalsent'] = 'Sinyal gnderildi.';
        $lang['strsignalsentbad'] = 'Sinyal gnderme ilemi baarsz oldu';
        $lang['strallobjects'] = 'Tm nesneler';
	$lang['strdatabasealtered']  =  'Veritaban deitirildi.';
	$lang['strdatabasealteredbad']  =  'Veritaban deitirme baarsz oldu.';

	// Views
	$lang['strview'] = 'View';
	$lang['strviews'] = 'Viewlar';
	$lang['strshowallviews'] = 'Tm viewlar gster';
	$lang['strnoview'] = 'Bir view bulunamad.';
	$lang['strnoviews'] = 'Bir view bulunamad.';
	$lang['strcreateview'] = 'View yarat';
	$lang['strviewname'] = 'View ad';
	$lang['strviewneedsname'] = 'View iin bir ad belirtmelisiniz.';
	$lang['strviewneedsdef'] = 'View iin bir tanm belirtmelisiniz.';
	$lang['strviewneedsfields']  =  'View iinde grnmesini istediiniz kolonlar belirtmelisiniz.';
 	$lang['strviewcreated'] = 'View yaratld.';
	$lang['strviewcreatedbad'] = 'View yaratma ilemi baarsz oldu.';
	$lang['strconfdropview'] = '"%s" viewini kaldrmak istediinize emin misiniz?';
	$lang['strviewdropped'] = 'View kaldrld.';
	$lang['strviewdroppedbad'] = 'View kaldrma ilemi baarsz oldu.';
	$lang['strviewupdated'] = 'View gncellendi.';
	$lang['strviewupdatedbad'] = 'View gncelleme ilemi baarsz oldu.';
	$lang['strviewlink']  =  'Linking Keys';
	$lang['strviewconditions']  =  'Ek durumlar';
	$lang['strcreateviewwiz']  =  'Sihirbaz ile view yaratn';

	// Sequences
	$lang['strsequence'] = 'Sequence';
	$lang['strsequences'] = 'Sequences';
	$lang['strshowallsequences'] = 'Show all sequences';
	$lang['strnosequence'] = 'No sequence found.';
	$lang['strnosequences'] = 'No sequences found.';
	$lang['strcreatesequence'] = 'Create sequence';
	$lang['strlastvalue'] = 'Son deer';
	$lang['strincrementby'] = 'Arttrma deeri';	
	$lang['strstartvalue'] = 'Balang Deeri';
	$lang['strmaxvalue'] = 'Max Deer';
	$lang['strminvalue'] = 'Min Deer';
	$lang['strcachevalue'] = 'Cache Deeri';
	$lang['strlogcount'] = 'Log Count';
	$lang['striscycled'] = 'Is Cycled?';
	$lang['strsequenceneedsname'] = 'Sequence iin bir ad belirtmelisiniz.';
	$lang['strsequencecreated'] = 'Sequence yaratld.';
	$lang['strsequencecreatedbad'] = 'Sequence yaratma ilemi baarsz oldu.'; 
	$lang['strconfdropsequence'] = '"%s" sequence ini kaldrmak istediinize emin misiniz?';
	$lang['strsequencedropped'] = 'Sequence kaldrld.';
	$lang['strsequencedroppedbad'] = 'Sequence kaldrma ilemi baarsz oldu.';
	$lang['strsequencereset'] = 'Sequence sfrland.';
	$lang['strsequenceresetbad'] = 'Sequence sfrlama baarsz oldu.';

	// Indexes
	$lang['strindex']  =  'Index';
	$lang['strindexes'] = 'Indeksler';
	$lang['strindexname'] = 'Indeks ad';
	$lang['strshowallindexes'] = 'Tm indeksleri gster';
	$lang['strnoindex'] = 'Hibir indeks bulunamad.';
	$lang['strnoindexes'] = 'Hibir indeks bulunamad.';
	$lang['strcreateindex'] = 'Indeks yarat';
	$lang['strtabname'] = 'Tab Ad';
	$lang['strcolumnname'] = 'Kolon ad';
	$lang['strindexneedsname'] = 'Indeksinize bir ad vermeniz gerekmektedir.';
	$lang['strindexneedscols'] = 'Geerli koln says vermeniz gerekmektedir.';
	$lang['strindexcreated'] = 'Indeks yaratld.';
	$lang['strindexcreatedbad'] = 'Index creation failed.';
	$lang['strconfdropindex'] = '"%s" indeksini kaldrmak istediinize emin misiniz?';
	$lang['strindexdropped'] = 'Indeks kaldrld.';
	$lang['strindexdroppedbad'] = 'Indeks kaldrlamad.';
	$lang['strkeyname'] = 'Anahtar ad';
	$lang['struniquekey'] = 'Tekil (Unique) Anahtar';
	$lang['strprimarykey'] = 'Birincil Anahtar (Primary Key)';
 	$lang['strindextype'] = 'Indeksin tipi';
	$lang['strtablecolumnlist'] = 'Tablodaki kolonlar';
	$lang['strindexcolumnlist'] = 'Indeksteki kolonlar';
	$lang['strconfcluster']  =  '"%s" tablosunu cluster etmek istiyor musunuz?';
	$lang['strclusteredgood']  =  'Cluster tamamland.';
	$lang['strclusteredbad']  =  'Cluster baarsz oldu.';

	// Rules
	$lang['strrules'] = 'Rules';
	$lang['strrule'] = 'Rule';
	$lang['strshowallrules'] = 'Show all Rules';
	$lang['strnorule'] = 'Rule bulunamad.';
	$lang['strnorules'] = 'Rule bulunamad.';
	$lang['strcreaterule'] = 'Rule yarat';
	$lang['strrulename'] = 'Rule ad';
	$lang['strruleneedsname'] = 'Rule iin bir ad belirtmelisiniz.';
	$lang['strrulecreated'] = 'Rule yaratld.';
	$lang['strrulecreatedbad'] = 'Rule yaratma ilemi baarsz oldu.';
	$lang['strconfdroprule'] = '"%s" kuraln "%s" tablosundan silmek istediinize emin misiniz?';
	$lang['strruledropped'] = 'Rule silindi';
	$lang['strruledroppedbad'] = 'Rule silinme ilemi baarsz oldu.';

	// Constraints
	$lang['strconstraint']  =  'Kstlama';
	$lang['strconstraints'] = 'Kstlamalar';
	$lang['strshowallconstraints'] = 'Tm kstlamalar (constraint) gster.';
	$lang['strnoconstraints'] = 'Hibir kstlama (constraint) bulunamad.';
	$lang['strcreateconstraint'] = 'Kstlama (Constraint) yarat';
	$lang['strconstraintcreated'] = 'Kstlama (Constraint) yaratld.';
	$lang['strconstraintcreatedbad'] = 'Kstlama (Constraint) yaratma ilemi baarsz oldu.';
	$lang['strconfdropconstraint'] = '"%s" zerindeki "%s" kstlamasn (constraint) kaldrmak istiyor musunuz?';
	$lang['strconstraintdropped'] = 'Kstlama (Constraint) kaldrld';
	$lang['strconstraintdroppedbad'] = 'Kstlama (Constraint) ilemi baarsz oldu.';
	$lang['straddcheck'] = 'Kontrol (Check) ekle';
	$lang['strcheckneedsdefinition'] = 'Kontrol (Check) kstlamas (constraint) iin bir tanm girilmelidir.';
	$lang['strcheckadded'] = 'Kontrol kstlamas (Check constraint) eklendi.';
	$lang['strcheckaddedbad'] = 'Kontrol kstlamas (Check constraint) ekleme ilemi baarsz oldu.';
	$lang['straddpk'] = 'Birincil Anahtar Ekle';
	$lang['strpkneedscols'] = 'Birincil anahtar iin en az bir kolon gereklidir.';
	$lang['strpkadded'] = 'Birincil anahtar eklendi.';
	$lang['strpkaddedbad'] = 'Birincil anahtar eklenemedi.';
	$lang['stradduniq'] = 'Tekil (Unique) anahtar ekle';
	$lang['struniqneedscols'] = 'Tekil anahtar yaratmak iin en az bir kolon gerekir.';
	$lang['struniqadded'] = 'Tekil anahtar eklendi.';
	$lang['struniqaddedbad'] = 'Tekil anahtar eklenemedi.';
	$lang['straddfk'] = 'kincil anahtar ekle';
	$lang['strfkneedscols'] = 'kincil anahtar yaratmak iin en az bir kolon gerekir.';
	$lang['strfkneedstarget'] = 'kincil anahtar hedef bir tablo gerektirir.';
	$lang['strfkadded']  =  'kincil anahtar eklendi.';
	$lang['strfkaddedbad'] = 'kincil anahtar eklenemedi.';
	$lang['strfktarget'] = 'Hedef tablo';

	$lang['strfkcolumnlist'] = 'Anahtardaki kolonlar';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';
	// Functions
	$lang['strfunction'] = 'Fonksiyon';
	$lang['strfunctions'] = 'Fonksiyonlar';
	$lang['strshowallfunctions'] = 'Tm fonksiyonlar gster';
	$lang['strnofunction'] = 'Fonksiyon bulunamad.';
	$lang['strnofunctions'] = 'Fonksiyon bulunamad.';
	$lang['strcreateplfunction'] = 'SQL/PL fonksiyonu yarat';
        $lang['strcreateinternalfunction'] = ' (internal) fonksiyon yarat';
        $lang['strcreatecfunction'] = 'C fonksiyonu yarat';
	$lang['strfunctionname'] = 'Fonksiyon ad';
	$lang['strreturns'] = 'Dnderilen deer';
	$lang['strarguments'] = 'Argmanlar';
	$lang['strproglanguage'] = 'Dil';
	$lang['strfunctionneedsname'] = 'Fonksiyona bir ad vermelisiniz.';
	$lang['strfunctionneedsdef'] = 'Fonksiyona bir tanm vermelisiniz.';
	$lang['strfunctioncreated'] = 'Fonksiyon yaratld.';
	$lang['strfunctioncreatedbad'] = 'Fonksiyon yaratma ilemi baarsz oldu.';
	$lang['strconfdropfunction'] = '"%s" fonksiyonunu kaldrmak istediinize emin misiniz?';
	$lang['strfunctiondropped'] = 'Fonksiyon kaldrld.';
	$lang['strfunctiondroppedbad'] = 'Fonksiyon kaldrma ilemi baarsz oldu.';
	$lang['strfunctionupdated'] = 'Fonksiyon gncellendi.';
	$lang['strfunctionupdatedbad'] = 'Function gncelleme ilemi baarsz oldu.';
	$lang['strobjectfile'] = 'Nesne dosyas';
        $lang['strlinksymbol'] = 'Balant sembol';

	// Triggers
	$lang['strtrigger'] = 'Trigger';
	$lang['strtriggers'] = 'Triggerlar';
	$lang['strshowalltriggers'] = 'Tm triggerlar gster';
	$lang['strnotrigger'] = 'Trigger bulunamad.';
	$lang['strnotriggers'] = 'Trigger bulunamad.';
	$lang['strcreatetrigger'] = 'Yeni trigger yarat';
	$lang['strtriggerneedsname'] = 'Trigger iin bir ad belirtmelisiniz.';
	$lang['strtriggerneedsfunc'] = 'Trigger iin bir fonksiyon belirtmelisiniz.';
	$lang['strtriggercreated'] = 'Trigger yaratld.';
	$lang['strtriggercreatedbad'] = 'Trigger yaratlamad.';
	$lang['strconfdroptrigger'] = '"%s" triggerini "%s" tablosundan kaldrmak istediinize emin misiniz?';
	$lang['strtriggerdropped'] = 'Trigger silindi.';
	$lang['strtriggerdroppedbad'] = 'Trigger silinme ilemi baarsz oldu.';
	$lang['strtriggeraltered']  =  'Trigger deitirildi.';
	$lang['strtriggeralteredbad']  =  'Trigger deitirilme ilemi baarsz oldu.';
	$lang['strforeach']  =  'Her bir';

	// Types
	$lang['strtype'] = 'Veri tipi';
	$lang['strtypes'] = 'Veri tipleri';
	$lang['strshowalltypes'] = 'Tm veri tiplerini gster';
	$lang['strnotype'] = 'Hi veri tipi bulunamad.';
	$lang['strnotypes'] = 'Hi veri tipi bulunamad.';
	$lang['strcreatetype'] = 'Yeni veri tipi yarat';
        $lang['strcreatecomptype'] = 'Karmak veri tipi yarat';
        $lang['strtypeneedsfield'] = 'En az bir alan belirtmelisiniz.';
        $lang['strtypeneedscols'] = 'Geerli bir alan says belirtmelisiniz.';
	$lang['strtypename'] = 'Veri tipi ad';
	$lang['strinputfn'] = 'Giri (Input) fonksiyonu';
	$lang['stroutputfn'] = 'k (Output) fonksiyonu';
	$lang['strpassbyval'] = 'Passed by val?';
	$lang['stralignment'] = 'Alignment';
	$lang['strelement'] = 'Eleman';
	$lang['strdelimiter'] = 'Delimiter';
	$lang['strstorage'] = 'Storage';
	$lang['strfield']  =  'Alan';
	$lang['strnumfields']  =  'Alanlarn says';

	$lang['strtypeneedsname'] = 'Veri tipi iin bir ad vermelisiniz.';
	$lang['strtypeneedslen'] = 'Veri tipiniz iin bir uzunluk belirtmelisiniz.';
	$lang['strtypecreated'] = 'Veri tipi yaratld';
	$lang['strtypecreatedbad'] = 'Veri tipi yaratlamad.';
	$lang['strconfdroptype'] = '"%s" veri tipini kaldrmak istediinize emin misiniz?';
	$lang['strtypedropped'] = 'Veri tipi kaldrld.';
	$lang['strtypedroppedbad'] = 'Veri tipi kaldrlamad.';
        $lang['strflavor'] = 'Flavor';
        $lang['strbasetype'] = 'Base';
        $lang['strcompositetype'] = 'Composite';
        $lang['strpseudotype'] = 'Pseudo';

	// Schemas
	$lang['strschema'] = 'ema';
	$lang['strschemas'] = 'emalar';
	$lang['strshowallschemas'] = 'Tm emalar gster';
	$lang['strnoschema'] = 'Bir ema bulunamad.';
	$lang['strnoschemas'] = 'Bir ema bulunamad.';
	$lang['strcreateschema'] = 'ema yarat';
	$lang['strschemaname'] = 'ema ad';
	$lang['strschemaneedsname'] = 'ema iin bir ad belirtmelisiniz.';
	$lang['strschemacreated'] = 'ema yaratld';
	$lang['strschemacreatedbad'] = 'ema yaratma ilemi baarsz oldu';
	$lang['strconfdropschema'] = '"%s" emasn kaldrmak istediinize emin misiniz?';
	$lang['strschemadropped'] = 'ema kaldrld.';
	$lang['strschemadroppedbad'] = 'ema kaldrma ilemi baarsz oldu.';
	$lang['strschemaaltered']  =  'Schema deitirildi.';
	$lang['strschemaalteredbad']  =  'Schema deitirilme ilemi baarsz oldu.';
	$lang['strsearchpath'] = 'ema arama yolu';

	// Reports
	$lang['strreport'] = 'Rapor';
	$lang['strreports'] = 'Raporlar';
	$lang['strshowallreports'] = 'Tm raporlar gster';
	$lang['strnoreports'] = 'Hibir rapor bulunamad';
	$lang['strcreatereport'] = 'Rapor yaratld.';
	$lang['strreportdropped'] = 'Rapor silindi';
	$lang['strreportdroppedbad'] = 'Rapor silme ii baarsz oldu.';
	$lang['strconfdropreport'] = '"%s" raporunu silmek istediinize emin misiniz?';
	$lang['strreportneedsname'] = 'Raporunuza bir ad vermelisiniz.';
	$lang['strreportneedsdef'] = 'Raporunuz iin SQL sorgular yazmalsnz.';
	$lang['strreportcreated'] = 'Rapor kaydedildi.';
	$lang['strreportcreatedbad'] = 'Rapor kaydetme baarsz oldu.';
	$lang['strdomain'] = 'Domain';
	$lang['strdomains'] = 'Domainler';
	$lang['strshowalldomains'] = 'Tm domainleri gster.';
	$lang['strnodomains'] = 'Hibir domain bulunamad.';
	$lang['strcreatedomain'] = 'Domain yarat';
	$lang['strdomaindropped'] = 'Domain silindi.';
	$lang['strdomaindroppedbad'] = 'Domain silme baarsz oldu.';
	$lang['strconfdropdomain'] = '"%s" domain\'ini silmek istediinize emin misiniz??';
	$lang['strdomainneedsname'] = 'Domain iin bir ad vermelisiniz.';
	$lang['strdomaincreated'] = 'Domain yaratld.';
	$lang['strdomaincreatedbad'] = 'Domain yaratma baarsz oldu.';
	$lang['strdomainaltered'] = 'Domain alter edildi.';
	$lang['strdomainalteredbad'] = 'Domain alter ilemi baarsz oldu.';

	$lang['stroperator'] = 'Operatr';
	$lang['stroperators']  =  'Operatrler';
	$lang['strshowalloperators'] = 'Tm operatrleri gster';
	$lang['strnooperator'] = 'Operatr bulunamad.';
	$lang['strnooperators'] = 'Operatr bulunamad.';
	$lang['strcreateoperator'] = 'Operatr yaratld.';
	$lang['strleftarg'] = 'Sol Arg Tipi';
	$lang['strrightarg'] = 'Sa Arg Tipi';
	$lang['strcommutator'] = 'Commutator';
	$lang['strnegator'] = 'Negator';
	$lang['strrestrict'] = 'Restrict';
	$lang['strjoin'] = 'Join';
	$lang['strhashes'] = 'Hashes';
	$lang['strmerges'] = 'Merges';
	$lang['strleftsort'] = 'Left sort';
	$lang['strrightsort'] = 'Right sort';
	$lang['strlessthan'] = 'kktr';
	$lang['strgreaterthan'] = 'byktr';
	$lang['stroperatorneedsname']  =  'Operatre bir ad vermelisiniz.';
	$lang['stroperatorcreated']  =  'Operatr yaratld';
	$lang['stroperatorcreatedbad']  =  'Operatr yaratma ilemi baarsz oldu.';
	$lang['strconfdropoperator']  =  '"%s" operatrn kaldrmak istediinize emin misiniz?';
	$lang['stroperatordropped']  =  'Operatr kaldrld.';
	$lang['stroperatordroppedbad']  =  'Operator kaldrma ilemi baarsz oldu.';

	// Casts
	$lang['strcasts'] = 'Casts';
	$lang['strnocasts'] = 'Hi cast bulunamad.';
	$lang['strsourcetype'] = 'Kaynak tip';
	$lang['strtargettype'] = 'Hedef tip';
	$lang['strimplicit'] = 'Implicit';
	$lang['strinassignment'] = 'In assignment';
	$lang['strbinarycompat'] = '(Binary uyumlu)';
	
	// Conversions
	$lang['strconversions'] = 'Dnmleri';
	$lang['strnoconversions'] = 'Hi dnm bulunamad.';
	$lang['strsourceencoding'] = 'Kaynak dil kodlamas';
	$lang['strtargetencoding'] = 'Hedef dil kodlamas';
	
	// Languages
	$lang['strlanguages'] = 'Diller';
	$lang['strnolanguages'] = 'Hi bir dil bulunamad.';
	$lang['strtrusted'] = 'Gvenilir';
	
	// Info
	$lang['strnoinfo'] = 'Hi bir bilgi yok.';
	$lang['strreferringtables'] = 'Referring tables';
	$lang['strparenttables'] = 'Parent tablolar';
	$lang['strchildtables'] = 'Child tablolar';
	
	// Aggregates
	$lang['straggregates']  =  'Aggregate';
	$lang['strnoaggregates'] = 'Hi aggregate bulunamad.';
	$lang['stralltypes'] = '(Tm veri tipleri)';
	$lang['stropclasses'] = 'Op snflar';
	$lang['strnoopclasses'] = 'Hi operatr snf bulunamad.';
	$lang['straccessmethod'] = 'Eriim Yntemi';
	$lang['strrowperf'] = 'Satr Baarm';
	$lang['strioperf'] = 'I/O Baarm';
	$lang['stridxrowperf'] = 'Index Satr Baarm';
	$lang['stridxioperf'] = 'Index I/O Baarm';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Sequential';
	$lang['strscan'] = 'Scan';
	$lang['strread'] = 'Read';
	$lang['strfetch'] = 'Fetch';
	$lang['strheap'] = 'Heap';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST Index';
	$lang['strcache'] = 'Cache';
	$lang['strdisk'] = 'Disk';
	$lang['strrows2'] = 'Rows';

	// Tablespaces
	$lang['strtablespace'] = 'Tablespace';
	$lang['strtablespaces'] = 'Tablespaceler';
	$lang['strshowalltablespaces'] = 'Tm tablespaceleri gster';
	$lang['strnotablespaces'] = 'Hi tablespace bulunamad.';
	$lang['strcreatetablespace'] = 'Tablespace yarat';
	$lang['strlocation'] = 'Yer';
	$lang['strtablespaceneedsname'] = 'Tablespace\'e bir ad vermelisiniz.';
	$lang['strtablespaceneedsloc'] = 'Tablespace\'in yaratlaca dizini belirtmelisiniz';
	$lang['strtablespacecreated'] = 'Tablespace yaratld.';
	$lang['strtablespacecreatedbad'] = 'Tablespace yaratlamad.';
	$lang['strconfdroptablespace'] = '"%s" adl tablespace\'i kaldrmak istediinize emin misiniz?';
	$lang['strtablespacedropped'] = 'Tablespace kaldrld.';
	$lang['strtablespacedroppedbad'] = 'Tablespace kaldrlamad.';
	$lang['strtablespacealtered'] = 'Tablespace deitirildi.';
	$lang['strtablespacealteredbad'] = 'Tablespace deitirilemedi.';

	// Slony clusters
	$lang['strcluster']  =  'Kme';
	$lang['strnoclusters']  =  'Hi kme bulunamad.';
	$lang['strconfdropcluster']  =  '"%s" kmesini kaldrmak istediinize emin misiniz?';
	$lang['strclusterdropped']  =  'Kme kaldrld.';
	$lang['strclusterdroppedbad']  =  'Kme kaldrma ilemi baarsz oldu.';
	$lang['strinitcluster']  =  'Kmeyi ilklendir';
	$lang['strclustercreated']  =  'Kme ilklendirildi.';
	$lang['strclustercreatedbad']  =  'Kme ilklendirme baarsz oldu.';
	$lang['strclusterneedsname']  =  'Kme iin bir ad vermelisiniz.';
	$lang['strclusterneedsnodeid']  =  'Yerel u iin bir ID vermelisiniz.';
	
	// Slony nodes
	$lang['strnodes']  =  'Ular';
	$lang['strnonodes']  =  'Hi u bulunamad.';
	$lang['strcreatenode']  =  'U yarat';
	$lang['strid']  =  'ID';
	$lang['stractive']  =  'Etkin';
	$lang['strnodecreated']  =  'U yaratld.';
	$lang['strnodecreatedbad']  =  'U yaratma baarsz oldu.';
	$lang['strconfdropnode']  =  '"%s" adl ucu kaldrmak istediinize emin misiniz?';
	$lang['strnodedropped']  =  'U kaldrld.';
	$lang['strnodedroppedbad']  =  'U kaldrma baarsz oldu.';
	$lang['strfailover']  =  'Failover';
$lang['strnodefailedover']  =  'Node failed over.';
$lang['strnodefailedoverbad']  =  'Node failover failed.';
	
	// Slony paths	
$lang['strpaths']  =  'Paths';
$lang['strnopaths']  =  'No paths found.';
$lang['strcreatepath']  =  'Create path';
	$lang['strnodename']  =  'U ad';
$lang['strnodeid']  =  'Node ID';
$lang['strconninfo']  =  'Connection string';
	$lang['strconnretry']  =  'yeniden balanmadan nce ka saniye gerekecek';
$lang['strpathneedsconninfo']  =  'You must give a connection string for the path.';
$lang['strpathneedsconnretry']  =  'You must give the number of seconds to wait before retry to connect.';
$lang['strpathcreated']  =  'Path created.';
$lang['strpathcreatedbad']  =  'Path creation failed.';
$lang['strconfdroppath']  =  'Are you sure you want to drop path "%s"?';
$lang['strpathdropped']  =  'Path dropped.';
$lang['strpathdroppedbad']  =  'Path drop failed.';

	// Slony listens
$lang['strlistens']  =  'Listens';
$lang['strnolistens']  =  'No listens found.';
$lang['strcreatelisten']  =  'Create listen';
$lang['strlistencreated']  =  'Listen created.';
$lang['strlistencreatedbad']  =  'Listen creation failed.';
$lang['strconfdroplisten']  =  'Are you sure you want to drop listen "%s"?';
$lang['strlistendropped']  =  'Listen dropped.';
$lang['strlistendroppedbad']  =  'Listen drop failed.';

	// Slony replication sets
	$lang['strrepsets']  =  'Replikasyon kmesi';
	$lang['strnorepsets']  =  'Hi replikasyon kmesi bulunamad.';
	$lang['strcreaterepset']  =  'Replikasyon kmesi yarat';
	$lang['strrepsetcreated']  =  'Replikasyon kmesi yaratld.';
	$lang['strrepsetcreatedbad']  =  'Replikasyon kmesi yaratma baarsz oldu.';
$lang['strconfdroprepset']  =  'Are you sure you want to drop replication set "%s"?';
	$lang['strrepsetdropped']  =  'Replikasyon kmesi kaldrld.';
	$lang['strrepsetdroppedbad']  =  'Replikasyon kmesi kaldrma baarsz oldu.';
$lang['strmerge']  =  'Merge';
$lang['strmergeinto']  =  'Merge into';
$lang['strrepsetmerged']  =  'Replication sets merged.';
$lang['strrepsetmergedbad']  =  'Replication sets merge failed.';
	$lang['strmove']  =  'Ta';
$lang['strneworigin']  =  'New origin';
	$lang['strrepsetmoved']  =  'Replikasyon kmesi tand.';
	$lang['strrepsetmovedbad']  =  'Replikasyon kmesi tama baarsz oldu.';
	$lang['strnewrepset']  =  'Yeni replikasyon kmesi';
	$lang['strlock']  =  'Kilitle';
	$lang['strlocked']  =  'Kilitlendi';
	$lang['strunlock']  =  'Kilidi a';
	$lang['strconflockrepset']  =  '"%s" replikasyon kmesini kilitlemek istediinize emin misiniz?';
	$lang['strrepsetlocked']  =  'Replikasyon kmesi kilitlendi.';
	$lang['strrepsetlockedbad']  =  'Replikasyon kmesi kilitleme baarsz oldu.';
$lang['strconfunlockrepset']  =  'Are you sure you want to unlock replication set "%s"?';
	$lang['strrepsetunlocked']  =  'Replikasyon kmesinin kilidi ald.';
$lang['strrepsetunlockedbad']  =  'Replikasyon kmesi kilit ama baarsz oldu.';
$lang['strexecute']  =  'Execute';
$lang['stronlyonnode']  =  'Only on node';
	$lang['strddlscript']  =  'DDL betii';
$lang['strscriptneedsbody']  =  'You must supply a script to be executed on all nodes.';
$lang['strscriptexecuted']  =  'Replication set DDL script executed.';
$lang['strscriptexecutedbad']  =  'Failed executing replication set DDL script.';
$lang['strtabletriggerstoretain']  =  'The following triggers will NOT be disabled by Slony:';

	// Slony tables in replication sets
	$lang['straddtable']  =  'Tablo ekle';
$lang['strtableneedsuniquekey']  =  'Table to be added requires a primary or unique key.';
$lang['strtableaddedtorepset']  =  'Table added to replication set.';
$lang['strtableaddedtorepsetbad']  =  'Failed adding table to replication set.';
$lang['strconfremovetablefromrepset']  =  'Are you sure you want to remove the table "%s" from replication set "%s"?';
$lang['strtableremovedfromrepset']  =  'Table removed from replication set.';
$lang['strtableremovedfromrepsetbad']  =  'Failed to remove table from replication set.';

	// Slony sequences in replication sets
$lang['straddsequence']  =  'Add sequence';
$lang['strsequenceaddedtorepset']  =  'Sequence added to replication set.';
$lang['strsequenceaddedtorepsetbad']  =  'Failed adding sequence to replication set.';
$lang['strconfremovesequencefromrepset']  =  'Are you sure you want to remove the sequence "%s" from replication set "%s"?';
$lang['strsequenceremovedfromrepset']  =  'Sequence removed from replication set.';
$lang['strsequenceremovedfromrepsetbad']  =  'Failed to remove sequence from replication set.';

	// Slony subscriptions
	$lang['strsubscriptions']  =  'yelikler';
	$lang['strnosubscriptions']  =  'yelik bulunamad.';

	// Miscellaneous
	$lang['strtopbar']  =  '%s, %s:%s zerinde alyor-- "%s" kullancs ile sisteme giri yaptnz.';
        $lang['strtimefmt']  =  'jS M, Y g:iA';
        $lang['strhelp']  =  'Yardm';
	$lang['strhelpicon'] = '?';
	$lang['strlogintitle']  =  '%s\'e giri yap';
	$lang['strlogoutmsg']  =  '%s\'den kld.';
	$lang['strloading']  =  'Ykleniyor...';
	$lang['strerrorloading']  =  'Ykleme hatas';
	$lang['strclicktoreload']  =  'Yeniden yklemek iin tklayn.';

?>

